==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/updatenotification/l10n/lt_LT.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Yra prieinama {version}. Gaukite daugiau informacijos apie tai kaip atnaujinti.",
    "Update notifications" : "Atnaujinimų pranešimai",
    "Channel updated" : "Kanalas atnaujintas",
    "The update server could not be reached since %d days to check for new updates." : " Atnaujinimo serveris nepasiekiamas  %d dienas.",
    "Please check the Nextcloud and server log files for errors." : "Prašome patikrinti Nextcloud ir serverio žurnalų įrašus apie galimas klaidas.",
    "Update to %1$s is available." : "Yra prieinamas atnaujinimas į %1$s.",
    "Update for %1$s to version %2$s is available." : "Yra prieinamas %1$s atnaujinimas į versiją %2$s.",
    "Update for {app} to version %s is available." : "Yra prieinamas {app} atnaujinimas į versiją %s.",
    "Open updater" : "Atverti atnaujinimo programą",
    "Download now" : "Atsisiųsti dabar",
    "The update check is not yet finished. Please refresh the page." : "Atnaujinimų patikrinimas dar neužbaigtas. Prašome įkelti puslapį iš naujo.",
    "Your version is up to date." : "Jūsų versija yra naujausia.",
    "A non-default update server is in use to be checked for updates:" : "Atnaujinimų aptikimui yra naudojamas ne nenumatytasis serveris: ",
    "Update channel:" : "Atnaujinimo kanalas:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Visada galite atnaujinti į naujesnę versiją / eksperimentinį kanalą. Tačiau niekada negalite sendinti versijos ar persijungti į stabilų kanalą.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Turėkite omenyje, kad po naujos versijos išleidimo, gali praeiti šiek tiek laiko, kol ji čia taps matoma. Mes išleidžiame naujas versijas paskirstytas pagal laiką savo naudotojams ir, kartais, pastebėjus klaidas, praleidžiame versiją.",
    "Notify members of the following groups about available updates:" : "Apie galimus atnaujinimus informuoti narius iš grupių:",
    "Only notification for app updates are available." : "Yra prieinami tik pranešimai apie programėlių atnaujinimus.",
    "The selected update channel does not support updates of the server." : "Pasirinktas kanalas nepalaiko serverio atnaujinimų.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Yra prieinama nauja versija: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Tikrinta {lastCheckedDate}",
    "View changelog" : "Rodyti keitinių žurnalą",
    "Could not start updater, please try the manual update" : "Nepavyko paleisti atnaujinimo programos, prašome bandyti atnaujinimą rankiniu būdu",
    "A new version is available: %s" : "Yra prieinama nauja versija: %s",
    "Checked on %s" : "Tikrinta %s"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.14.tar.bz2: nextcloud/apps/updatenotification/l10n/lt_LT.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Yra prieinama {version}. Gaukite daugiau informacijos apie tai kaip atnaujinti.",
    "Channel updated" : "Kanalas atnaujintas",
    "Update notifications" : "Atnaujinimų pranešimai",
    "The update server could not be reached since %d days to check for new updates." : " Atnaujinimo serveris nepasiekiamas  %d dienas.",
    "Please check the Nextcloud and server log files for errors." : "Prašome patikrinti Nextcloud ir serverio žurnalų įrašus apie galimas klaidas.",
    "Update to %1$s is available." : "Yra prieinamas atnaujinimas į %1$s.",
    "Update for %1$s to version %2$s is available." : "Yra prieinamas %1$s atnaujinimas į versiją %2$s.",
    "Update for {app} to version %s is available." : "Yra prieinamas {app} atnaujinimas į versiją %s.",
    "Update notification" : "Atnaujinimų pranešimas",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Jūsų naudojama versija daugiau nebeprižiūrima. Esant galimybei, kaip įmanoma greičiau atnaujinkite į palaikomą versiją.",
    "View in store" : "Rodyti parduotuvėje",
    "Open updater" : "Atverti atnaujinimo programą",
    "Download now" : "Atsisiųsti dabar",
    "What's new?" : "Kas naujo?",
    "The update check is not yet finished. Please refresh the page." : "Atnaujinimų patikrinimas dar neužbaigtas. Prašome įkelti puslapį iš naujo.",
    "Your version is up to date." : "Jūsų versija yra naujausia.",
    "A non-default update server is in use to be checked for updates:" : "Atnaujinimų aptikimui yra naudojamas ne nenumatytasis serveris: ",
    "Update channel:" : "Atnaujinimo kanalas:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Visada galite atnaujinti į naujesnę versiją. Tačiau niekada negalite sendinti į stabilesnę versiją.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Turėkite omenyje, kad po naujos versijos išleidimo, gali praeiti šiek tiek laiko, kol ji čia taps matoma. Mes išleidžiame naujas versijas paskirstytas pagal laiką savo naudotojams ir, kartais, pastebėjus klaidas, praleidžiame versiją.",
    "Notify members of the following groups about available updates:" : "Apie galimus atnaujinimus informuoti narius iš grupių:",
    "Only notification for app updates are available." : "Yra prieinami tik pranešimai apie programėlių atnaujinimus.",
    "The selected update channel does not support updates of the server." : "Pasirinktas kanalas nepalaiko serverio atnaujinimų.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Yra prieinama nauja versija: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Tikrinta {lastCheckedDate}",
    "Checking apps for compatible updates" : "Tikrinama, ar yra suderinamų programėlių atnaujinimų",
    "View changelog" : "Rodyti keitinių žurnalą",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Visada galite atnaujinti į naujesnę versiją / eksperimentinį kanalą. Tačiau niekada negalite sendinti versijos ar persijungti į stabilų kanalą."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
